window.Gleam.initSearch([{"doc":"gtui","title":"gtui","content":"# gtui\n\n[![Package Version](https://img.shields.io/hexpm/v/gtui)](https://hex.pm/packages/gtui)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/gtui/)\n\nThis is inspired from TUI packages like [bubbleTea](https://github.com/charmbracelet/bubbletea)\n## To Add\n```sh\ngleam add gtui\n```\n\n## Usage\n\n```gleam\nimport gtui\n\nfn main(){\n    let state = State(...)\n    let appl = gtui.new_application(state, render, update, events)\n    gtui.run(appl)\n}\n```\n\n## components \n\n#### State\n\n```gleam\ntype State{\n    State(...)\n}\n```\nState is the information stored in the application, It can be store any type as needed  \n\n#### Message\n\n```gleam\ntype Message{\n    MessageA,\n    MessageB(Int)\n}\n```\n\nThese are all possible messages that the application needs to handle\n\n#### Render\n\n```gleam\nfn render(state: State) -&gt; String{\n    ...\n}\n```\n\nrender function takes the state of the application and returns the String that will be shown on the screen,  \nThe package takes care of replacing the previous render\n\n#### Update\n\n```gleam\nfn update(state: State, message: Message) -&gt; #(State, Bool){\n    ...\n}\n```\n\nThe function takes in a state and a message and returns the new state of the application and Bool denoting whether the Application keeps running or not\n\n#### Events\n\nEvents are a list of functions that return a Subject from the `gleam_erlang` library and a clean up function\n\n```gleam\nfn event() -&gt; #(process.Subject(Message), fn() -&gt; Nil){\n    ...\n}\n\nlet Events = [event]\n```\n\nAn Event is a function that will return a `process.Subject`, The intended use of this is to create a seperate process that will push messages onto the returned Subject,  \nthe package will poll the event and on recieving a message update the state of the application \n\nWe will also return a cleanup function which will be run before the application closes to run any code to clean up the events\n\n\n### Examples\nBasic Examples of a infinite spinner and a list is available in the `examples` folder\n\n----\n\nFurther documentation can be found at &lt;https://hexdocs.pm/tui&gt;.\n","url":"index.html"},{"doc":"gtui","title":"Application","content":"pub opaque type Application(state, message)\n\n\nSynonyms:\ngtui.Application\ngtui Application","url":"gtui.html#Application"},{"doc":"gtui","title":"new_application","content":"pub fn new_application(\n  state: a,\n  render: fn(a) -&gt; String,\n  update: fn(a, b) -&gt; #(a, Bool),\n  events: List(fn() -&gt; #(Subject(b), fn() -&gt; Nil)),\n) -&gt; Application(a, b)\n Constructor to create a new Application\nSynonyms:\ngtui.new_application\ngtui new_application","url":"gtui.html#new_application"},{"doc":"gtui","title":"on_alt_screen","content":"pub fn on_alt_screen(\n  appl: Application(a, b),\n) -&gt; Application(a, b)\n Make the application work on an alternative screen\nSynonyms:\ngtui.on_alt_screen\ngtui on_alt_screen","url":"gtui.html#on_alt_screen"},{"doc":"gtui","title":"run","content":"pub fn run(application: Application(a, b)) -&gt; Nil\n Start running an application\nSynonyms:\ngtui.run\ngtui run","url":"gtui.html#run"},{"doc":"gtui","title":"gtui","content":"","url":"gtui.html"}]);